<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PatientBar</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="96"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="135"/>
        <source>Name, Secondname - firstname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="20"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="39"/>
        <source>Search by Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="40"/>
        <source>Search by Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="41"/>
        <source>Search by Name and Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="42"/>
        <source>Search by Date Of Birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="44"/>
        <source>Type the name or second name of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="45"/>
        <source>Type the firstname of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="46"/>
        <source>Type the name or second name followed by ; and the firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="47"/>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="101"/>
        <source>Please enter the patient&apos;s identity.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="201"/>
        <source>born on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="215"/>
        <source>You must specify a birthname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
        <source>You can not create a patient without a birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
        <source>No birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="221"/>
        <source>You must specify a firstname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
        <source>You can not create a patient without a firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
        <source>No firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="227"/>
        <source>You must specify a date of birth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="228"/>
        <source>You can not create a patient without a date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="229"/>
        <source>No date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="233"/>
        <source>You must specify a gender.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="234"/>
        <source>You can not create a patient without a gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="235"/>
        <source>No gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="295"/>
        <source>Choose a photo</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="148"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="171"/>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="20"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="26"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="54"/>
        <source>Click to add/change the photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="73"/>
        <source>Birth Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="83"/>
        <source>Second name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="93"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="103"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="113"/>
        <source>Date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="123"/>
        <source>dd/MM/yyyy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
        <source>Adress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="142"/>
        <source>Street</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="149"/>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="159"/>
        <source>Zipcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="169"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>Fatal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="149"/>
        <source>%1 : Unable to retreive patients menu.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBase</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="322"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="330"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="336"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="346"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.cpp" line="67"/>
        <source>Patient database preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="20"/>
        <source>Patient selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
        <source>Use color to differentiate genders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="33"/>
        <source>Select newly created patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="56"/>
        <source>Patient bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="62"/>
        <source>Background color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::PatientBasePlugin</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="106"/>
        <location filename="../../plugins/patientbaseplugin/patientbaseplugin.cpp" line="153"/>
        <source>Initializing patients database plugin...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="59"/>
        <source>New Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="73"/>
        <source>WARNING ! You don&apos;t saved this patient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="74"/>
        <source>If you continue changes will be lost.
Do you really want to close this dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="76"/>
        <source>Patient not saved</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
